import parseDuration from './parseDuration.js';
/**
 * Parse a YouTube video object.
 *
 * @param videoData Video data from YouTube.
 * @returns Parsed YouTube video.
 */
const parseVideo = (videoData) => {
    // Parse video data.
    const id = videoData.videoId;
    const title = videoData.title.runs[0].text;
    const durationText = videoData.lengthText.simpleText;
    const duration = parseDuration(durationText);
    const url = `https://www.youtube.com/watch?v=${id}`;
    const thumbnails = videoData.thumbnail.thumbnails;
    // Parse channel data.
    const channelName = videoData.longBylineText.runs[0].text;
    const channelUrl = `https://youtube.com${videoData.longBylineText.runs[0].navigationEndpoint.commandMetadata.webCommandMetadata.url}`;
    const channelThumbnail = videoData.channelThumbnailSupportedRenderers.channelThumbnailWithLinkRenderer.thumbnail.thumbnails[0];
    return {
        id,
        title,
        durationText,
        duration,
        url,
        thumbnails,
        channel: {
            name: channelName,
            url: channelUrl,
            thumbnail: channelThumbnail
        }
    };
};
export default parseVideo;
//# sourceMappingURL=parseVideo.js.map